"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const class_transformer_1 = require("class-transformer");
const query_1 = require("../query");
class TypeormQueryService {
    constructor(repo, filterQueryBuilder = new query_1.FilterQueryBuilder(repo)) {
        this.repo = repo;
        this.filterQueryBuilder = filterQueryBuilder;
    }
    get entityType() {
        return this.repo.target;
    }
    query(query) {
        return this.filterQueryBuilder.select(query).getMany();
    }
    findById(id) {
        return this.repo.findOne(id);
    }
    getById(id) {
        return this.repo.findOneOrFail(id);
    }
    createOne(record) {
        return this.repo.save(this.ensureIsEntity(record));
    }
    createMany(records) {
        return this.repo.save(records.map(item => this.ensureIsEntity(item)));
    }
    async updateOne(id, update) {
        const entity = await this.getById(id);
        return this.repo.save(this.repo.merge(entity, update));
    }
    async updateMany(update, filter) {
        const updateResult = await this.filterQueryBuilder
            .update({ filter })
            .set({ ...update })
            .execute();
        return { updatedCount: updateResult.affected || 0 };
    }
    async deleteOne(id) {
        const entity = await this.getById(id);
        return this.repo.remove(entity);
    }
    async deleteMany(filter) {
        const deleteResult = await this.filterQueryBuilder.delete({ filter }).execute();
        return { deletedCount: deleteResult.affected || 0 };
    }
    ensureIsEntity(obj) {
        if (obj instanceof this.entityType) {
            return obj;
        }
        return class_transformer_1.plainToClass(this.entityType, obj);
    }
}
exports.TypeormQueryService = TypeormQueryService;
//# sourceMappingURL=typeorm-query.service.js.map